@@ -28,7 +28,7 @@ class BasicDataApi(object):
                 return tag_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {TradingDayList.__tablename__}')
 
     def get_sector_info(self):
         with BasicDatabaseConnector().managed_session() as db_session:
@@ -40,7 +40,7 @@ class BasicDataApi(object):
                 return ret_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {SectorInfo.__tablename__}')
 
     def get_sector_index_funds(self, index_id):
         with BasicDatabaseConnector().managed_session() as db_session:
@@ -54,7 +54,7 @@ class BasicDataApi(object):
                 return ret_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {SectorFunds.__tablename__}')
 
     def get_sector_main_index_id(self, sector_id):
         with BasicDatabaseConnector().managed_session() as db_session:
@@ -68,7 +68,7 @@ class BasicDataApi(object):
                 return ret_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {SectorInfo.__tablename__}')
 
     def get_sector_indices(self, sector_id):
         with BasicDatabaseConnector().managed_session() as db_session:
@@ -82,7 +82,7 @@ class BasicDataApi(object):
                 return ret_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {SectorFunds.__tablename__}')
 
     def get_fund_info(self):
         with BasicDatabaseConnector().managed_session() as db_session:
@@ -94,7 +94,7 @@ class BasicDataApi(object):
                 return tag_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {FundInfo.__tablename__}')
 
     def get_fund_benchmark(self):
         with BasicDatabaseConnector().managed_session() as db_session:
@@ -104,7 +104,7 @@ class BasicDataApi(object):
                     )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {FundBenchmark.__tablename__}')
 
     def get_index_info(self):
         with BasicDatabaseConnector().managed_session() as db_session:
@@ -116,7 +116,7 @@ class BasicDataApi(object):
                 return tag_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {IndexInfo.__tablename__}')
 
     def get_index_component(self, index_list: Tuple[str] = ()):
         with BasicDatabaseConnector().managed_session() as db_session:
@@ -143,7 +143,7 @@ class BasicDataApi(object):
                 return tag_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {StockInfo.__tablename__}')
 
     def get_fund_nav(self, fund_list):
         with BasicDatabaseConnector().managed_session() as db_session:
@@ -159,7 +159,7 @@ class BasicDataApi(object):
                 return tag_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {FundNav.__tablename__}')
 
     def delete_fund_nav(self, start_date, end_date):
         with BasicDatabaseConnector().managed_session() as db_session:
@@ -173,7 +173,7 @@ class BasicDataApi(object):
                 db_session.commit()
                 return True
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to delete data <err_msg> {e} from {FundNav.__tablename__}')
                 return None
                 
     def get_fund_nav_with_date(self, start_date, end_date, fund_list):
@@ -193,7 +193,7 @@ class BasicDataApi(object):
                 return tag_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {FundNav.__tablename__}')
 
     def get_stock_price(self, stock_list):
         with BasicDatabaseConnector().managed_session() as db_session:
@@ -209,7 +209,7 @@ class BasicDataApi(object):
                 return tag_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {StockPrice.__tablename__}')
 
     def get_fund_ret(self, fund_list):
         with BasicDatabaseConnector().managed_session() as db_session:
@@ -225,7 +225,7 @@ class BasicDataApi(object):
                 return tag_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {FundRet.__tablename__}')
 
     def get_index_price(self, index_list: Tuple[str] = ()):
         with BasicDatabaseConnector().managed_session() as db_session:
@@ -243,7 +243,7 @@ class BasicDataApi(object):
                 return tag_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {IndexPrice.__tablename__}')
 
     def delete_index_price(self, index_id_list, start_date, end_date):
         with BasicDatabaseConnector().managed_session() as db_session:
@@ -258,7 +258,7 @@ class BasicDataApi(object):
                 db_session.commit()
                 return True
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to delete data <err_msg> {e} from {IndexPrice.__tablename__}')
                 return None
 
     def get_fund_nav_adjusted_nv(self, fund_list, start_date, end_date):
@@ -278,29 +278,7 @@ class BasicDataApi(object):
                 return tag_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
-
-
-    def get_index_benchmark_data(self, index_list, start_date, end_date):
-        with BasicDatabaseConnector().managed_session() as db_session:
-            try:
-                query = db_session.query(
-                        IndexPrice.ret,
-                        IndexPrice.index_id,
-                        IndexPrice.datetime,
-                        IndexPrice.close,
-                ).filter(
-                        IndexPrice.index_id.in_(index_list),
-                        IndexPrice.datetime >= start_date,
-                        IndexPrice.datetime <= end_date,
-                    )
-
-                tag_df = pd.read_sql(query.statement, query.session.bind)
-                return tag_df
-
-            except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
-
+                print(f'Failed to get data <err_msg> {e} from {FundNav.__tablename__}')
 
     def get_fund_list(self):
         with BasicDatabaseConnector().managed_session() as db_session:
@@ -312,7 +290,7 @@ class BasicDataApi(object):
                 return tag_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {FundInfo.__tablename__}')
 
     def get_fund_fee(self):
         with BasicDatabaseConnector().managed_session() as db_session:
@@ -326,7 +304,7 @@ class BasicDataApi(object):
                 return tag_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {FundInfo.__tablename__}')
 
     def get_fund_asset(self):
         with BasicDatabaseConnector().managed_session() as db_session:
@@ -339,7 +317,7 @@ class BasicDataApi(object):
                 return tag_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {FundInfo.__tablename__}')
 
     def get_fund_id_mapping(self):
         fund_id_mapping = {}
@@ -359,7 +337,7 @@ class BasicDataApi(object):
                         {'fund_id': fund_id, 'start_date':start_date, 'end_date': end_date})
 
             except Exception as e:
-                print('Failed to get fund id mapping <err_msg> {}'.format(e))
+                print(f'Failed to get fund id mapping <err_msg> {e} from {FundInfo.__tablename__}')
                 return None
 
         return fund_id_mapping
@@ -374,7 +352,103 @@ class BasicDataApi(object):
                 return tag_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {FundSize.__tablename__}')
+
+    @staticmethod
+    def get_history_fund_size(fund_id):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    Fund_size_and_hold_rate,
+                ).filter(
+                    Fund_size_and_hold_rate.fund_id == fund_id
+                )
+                df = pd.read_sql(query.statement, query.session.bind)
+                return df
+
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {Fund_size_and_hold_rate.__tablename__}')
+                return pd.DataFrame([])
+
+    @staticmethod
+    def get_history_fund_rating(fund_id):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    FundRate,
+                ).filter(
+                    FundRate.fund_id == fund_id
+                )
+                df = pd.read_sql(query.statement, query.session.bind)
+                return df
+
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {FundRate.__tablename__}')
+                return pd.DataFrame([])
+
+    @staticmethod
+    def get_fund_hold_asset_by_id(fund_id):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    FundHoldAsset,
+                ).filter(
+                    FundHoldAsset.fund_id == fund_id,
+                )
+                df = pd.read_sql(query.statement, query.session.bind)
+                return df
+
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {FundHoldAsset.__tablename__}')
+                return pd.DataFrame([])
+
+    @staticmethod
+    def get_fund_hold_industry_by_id(fund_id):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    FundHoldIndustry,
+                ).filter(
+                    FundHoldIndustry.fund_id == fund_id,
+                )
+                df = pd.read_sql(query.statement, query.session.bind)
+                return df
+
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {FundHoldIndustry.__tablename__}')
+                return pd.DataFrame([])
+
+    @staticmethod
+    def get_fund_hold_stock_by_id(fund_id):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    FundHoldStock,
+                ).filter(
+                    FundHoldStock.fund_id == fund_id,
+                )
+                df = pd.read_sql(query.statement, query.session.bind)
+                return df
+
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {FundHoldStock.__tablename__}')
+                return pd.DataFrame([])
+
+    @staticmethod
+    def get_fund_hold_bond_by_id(fund_id):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    FundHoldBond,
+                ).filter(
+                    FundHoldBond.fund_id == fund_id,
+                )
+                df = pd.read_sql(query.statement, query.session.bind)
+                return df
+
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {FundHoldBond.__tablename__}')
+                return pd.DataFrame([])
 
     def get_style_analysis_data(self, start_date: str, end_date: str, stock_list: Tuple[str] = ()):
         with BasicDatabaseConnector().managed_session() as db_session:
