@@ -26,7 +26,7 @@ class DerivedDataApi(object):
                 return tag_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {FundIndicator.__tablename__}')
 
     def get_fund_indicator_by_date(self, fund_list, date):
         with DerivedDatabaseConnector().managed_session() as quant_session:
@@ -41,7 +41,7 @@ class DerivedDataApi(object):
                 return tag_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {FundIndicator.__tablename__}')
 
     def get_fund_indicator_monthly(self, start_date, end_date, fund_list, columns: Tuple[str] = ()):
         with DerivedDatabaseConnector().managed_session() as quant_session:
@@ -59,7 +59,7 @@ class DerivedDataApi(object):
                 )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {FundIndicatorMonthly.__tablename__}')
 
     def get_fund_score(self):
         with DerivedDatabaseConnector().managed_session() as quant_session:
@@ -71,7 +71,7 @@ class DerivedDataApi(object):
                 return tag_df
 
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {FundScore.__tablename__}')
 
     def get_index_valuation_develop(self, index_ids, start_date, end_date):
         with DerivedDatabaseConnector().managed_session() as mn_session:
@@ -86,7 +86,7 @@ class DerivedDataApi(object):
                 df = pd.read_sql(query.statement, query.session.bind)
                 return df
             except Exception as e:
-                print(e)
+                print(f'Failed to get data <err_msg> {e} from {IndexValuation.__tablename__}')
                 return pd.DataFrame([])
 
     def get_index_valuation_develop_without_date(self, index_ids):
@@ -100,7 +100,7 @@ class DerivedDataApi(object):
                 df = pd.read_sql(query.statement, query.session.bind)
                 return df
             except Exception as e:
-                print(e)
+                print(f'Failed to get data <err_msg> {e} from {IndexValuation.__tablename__}')
                 return pd.DataFrame([])
 
     def get_asset_allocation_info(self, version:int=2):
@@ -114,7 +114,7 @@ class DerivedDataApi(object):
                 df = pd.read_sql(query.statement, query.session.bind)
                 return df
             except Exception as e:
-                print(e)
+                print(f'Failed to get data <err_msg> {e} from {AssetAllocationInfo.__tablename__}')
                 return pd.DataFrame([])
 
     def get_style_factor_return(self, start_date: str, end_date: str, index_list: Tuple[str] = ()):
@@ -131,7 +131,7 @@ class DerivedDataApi(object):
                 )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
-                print('Failed to get_style_factor_return <err_msg> {}'.format(e))
+                print(f'Failed to get_style_factor_return {e} from {StyleAnalysisFactorReturn.__tablename__}')
                 return
 
     def get_allocation_distribution(self, version:str=1):
@@ -145,6 +145,6 @@ class DerivedDataApi(object):
                 df = pd.read_sql(query.statement, query.session.bind)
                 return df
             except Exception as e:
-                print('Failed to get_style_factor_return <err_msg> {}'.format(e))
+                print(f'Failed to get_style_factor_return {e} from {AllocationDistribution.__tablename__}')
                 return
 
