@@ -354,18 +354,21 @@ class RawDataApi:
                 print('Failed to get data <err_msg> {}'.format(e))
                 return None
 
-    def get_em_index_val(self, start_date, end_date, index_id_list):
+    def get_em_index_val(self, start_date, end_date, index_id_list: Tuple[str] = ()):
         with RawDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                     EmIndexVal
-                ).filter(
-                    EmIndexVal.CODES.in_(index_id_list),
+                )
+                if index_id_list:
+                    query = query.filter(
+                        EmIndexVal.CODES.in_(index_id_list),
+                    )
+                query = query.filter(
                     EmIndexVal.DATES >= start_date,
                     EmIndexVal.DATES <= end_date,
                 )
-                df = pd.read_sql(query.statement, query.session.bind)
-                return df
+                return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print('Failed to get data <err_msg> {}'.format(e))
                 return None
@@ -524,7 +527,7 @@ class RawDataApi:
                 )
                 if index_list:
                     query = query.filter(
-                        EmIndexInfo.em_id.in_(index_list)
+                        EmIndexInfo.CODES.in_(index_list)
                     )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
