@@ -28,6 +28,15 @@ class ViewDataApi(object):
                 print(e)
                 return False
 
-
-
+    @staticmethod
+    def get_daily_fund_automatic_investment():
+        with ViewDatabaseConnector().managed_session() as mn_session:
+            try:
+                query = mn_session.query(AutomaticInvestmentCollection)
+                df = pd.read_sql(query.statement, query.session.bind)
+                df = df.rename(columns=AutomaticInvestmentCollection.trans_columns())
+                return df
+            except Exception as e:
+                print(e)
+                return False
 
