@@ -17,7 +17,10 @@ class BasicFundRet(BasicDataPart1):
     M_3 = 60
     M_6 = 121
     Y_1 = 242
+    Y_3 = Y_1 * 3
+    Y_5 = Y_1 * 5
     SMALL_NUMBER = 1e-8
+    RISK_FEE_RATE = 0.025
 
     def __init__(self, data_helper: BasicDataHelper):
         self._data_helper = data_helper
@@ -34,7 +37,7 @@ class BasicFundRet(BasicDataPart1):
         self.index_list = list(set(self._fund_info_df.index_id))
         self._fund_to_enddate_dict = self._fund_info_df[['fund_id', 'end_date']].set_index('fund_id').to_dict()['end_date']
         self.fund_nav = self.fund_nav.pivot_table(index='datetime', columns='fund_id', values='adjusted_net_value').fillna(method='ffill')
-
+        self.fund_nav_fill = self.fund_nav.fillna(method='bfill').copy()
         # 超过基金终止日的基金净值赋空
         for fund_id in self.fund_nav.columns:
             fund_end_date = self._fund_to_enddate_dict[fund_id]
@@ -48,6 +51,8 @@ class BasicFundRet(BasicDataPart1):
         # 基金天数
         _get_days = lambda x : pd.Series(x).count()
         self.days = self.fund_nav.count() - 1
+        self.begin_day_of_year = datetime.date(self.end_date.year,1,1)
+        self.begin_day_of_year = self.fund_nav.index[self.fund_nav.index > self.begin_day_of_year][0]
 
     def get_annual_ret(self):
         '''
@@ -76,27 +81,33 @@ class BasicFundRet(BasicDataPart1):
         return 1 - (self.fund_nav / self.fund_nav.cummax()).min()
 
     def calculate_one_date(self):
-        self.w1_ret = self.fund_nav.iloc[-1] / self.fund_nav.iloc[-1 - self.W_1 ] - 1
-        self.m1_ret = self.fund_nav.iloc[-1] / self.fund_nav.iloc[-1 - self.M_1 ] - 1
-        self.m3_ret = self.fund_nav.iloc[-1] / self.fund_nav.iloc[-1 - self.M_3 ] - 1
-        self.m6_ret = self.fund_nav.iloc[-1] / self.fund_nav.iloc[-1 - self.M_6 ] - 1
-        self.y1_ret = self.fund_nav.iloc[-1] / self.fund_nav.iloc[-1 - self.Y_1 ] - 1
+        self.w1_ret = self.fund_nav_fill.tail(self.W_1+1).pct_change(self.W_1).tail(1).T.rename(columns={self.fund_nav.index[-1]:'w1_ret'})
+        self.m1_ret = self.fund_nav_fill.tail(self.M_1+1).pct_change(self.M_1).tail(1).T.rename(columns={self.fund_nav.index[-1]:'m1_ret'})
+        self.m3_ret = self.fund_nav_fill.tail(self.M_3+1).pct_change(self.M_3).tail(1).T.rename(columns={self.fund_nav.index[-1]:'m3_ret'})
+        self.m6_ret = self.fund_nav_fill.tail(self.M_6+1).pct_change(self.M_6).tail(1).T.rename(columns={self.fund_nav.index[-1]:'m6_ret'})
+        self.y1_ret = self.fund_nav_fill.tail(self.Y_1+1).pct_change(self.Y_1).tail(1).T.rename(columns={self.fund_nav.index[-1]:'y1_ret'})
+        self.y3_ret = self.fund_nav_fill.tail(self.Y_3+1).pct_change(self.Y_3).tail(1).T.rename(columns={self.fund_nav.index[-1]:'y3_ret'})
+        self.y5_ret = self.fund_nav_fill.tail(self.Y_5+1).pct_change(self.Y_5).tail(1).T.rename(columns={self.fund_nav.index[-1]:'y5_ret'})
 
-        self.total_ret = self.fund_nav.iloc[-1] / self.fund_nav.fillna(method = 'bfill').iloc[0]
+        self.total_ret = self.fund_nav_fill.iloc[-1] / self.fund_nav_fill.iloc[0]
         self.to_date_ret = self.total_ret - 1
         self.annual_ret = self.get_annual_ret()
         self.annual_vol = self.get_annual_vol()
-        self.sharpe_ratio = self.annual_ret / self.annual_vol
+        self.vol = self.fund_nav.pct_change(1).std(ddof=1)
+        self.sharpe_ratio = (self.annual_ret  - self.RISK_FEE_RATE) / self.annual_vol
         self.mdd = self.get_mdd()
+        self.recent_y_ret = self.fund_nav_fill.iloc[-1] / self.fund_nav_fill.loc[self.begin_day_of_year:].fillna(method = 'bfill').iloc[0] - 1
 
-        data_list = [self.w1_ret, self.m1_ret, self.m3_ret, self.m6_ret, self.y1_ret, self.to_date_ret, self.fund_scale, self.annual_ret, self.sharpe_ratio, self.mdd]
-        fac_list = ['w1_ret', 'm1_ret', 'm3_ret', 'm6_ret', 'y1_ret', 'to_date_ret', 'avg_size', 'annual_ret', 'sharpe_ratio', 'mdd']
+        data_list = [self.w1_ret, self.m1_ret, self.m3_ret, self.m6_ret, self.y1_ret, self.y3_ret, self.y5_ret, self.to_date_ret, self.fund_scale, self.annual_ret, self.sharpe_ratio, self.mdd, self.recent_y_ret,self.vol]
+        fac_list = ['w1_ret', 'm1_ret', 'm3_ret', 'm6_ret', 'y1_ret', 'y3_ret', 'y5_ret', 'to_date_ret', 'avg_size', 'annual_ret', 'sharpe_ratio', 'mdd', 'recent_y_ret','vol']
         self.res = []
         for name, data in zip(fac_list, data_list):
             df = pd.DataFrame(data).rename(columns = {0:name,self.fund_nav.index[-1]:'avg_size'})
             self.res.append(df)
         self.result = pd.concat(self.res, axis=1, sort=True).reset_index().rename(columns={'index':'fund_id'})
         self.result['datetime'] = self.fund_nav.index[-1]
+        self.result['info_ratio'] = None # TODO
+        self.result = self.result.replace(np.inf,None).replace(-np.inf,None)
 
     def process_all(self, end_date):
         failed_tasks = []
