@@ -184,6 +184,7 @@ class EmRawDataDownloader:
             start_date = datetime.datetime.strptime(start_date, '%Y%m%d') - datetime.timedelta(days=5)
             start_date = start_date.strftime('%Y%m%d')
             if not fund_id_list:
+                # 这里删掉之前几天的数据，然后再重刷一遍
                 self.delete_em_fund_nav(start_date, end_date)
                 fund_id_result = c.sector('507013', end_date)
                 if fund_id_result.ErrorCode != 0:
@@ -636,7 +637,7 @@ class EmRawDataDownloader:
                              NETWORKINGCAPITAL,TANGIBLEASSET,RETAINED,INTERESTLIBILITY,NETLIBILITY,EXINTERESTCL,EXINTERESTNCL,FCFF,FCFE,DA,FCFFDRIVE,\
                              PERFORMANCEEXPRESSPARENTNI,MBSALESCONS,GPMARGIN,NPMARGIN,EXPENSETOOR,INVTURNRATIO,ARTURNRATIO,ROEAVG,ROEWA,EPSBASIC,EPSDILUTED,\
                              BPS,BALANCESTATEMENT_25,BALANCESTATEMENT_46,BALANCESTATEMENT_93,BALANCESTATEMENT_103,BALANCESTATEMENT_141,BALANCESTATEMENT_195,\
-                             BALANCESTATEMENT_140,INCOMESTATEMENT_9,INCOMESTATEMENT_48,INCOMESTATEMENT_60,INCOMESTATEMENT_61,INCOMESTATEMENT_85,INCOMESTATEMENT_127,\
+                             BALANCESTATEMENT_140,INCOMESTATEMENT_9,INCOMESTATEMENT_48,INCOMESTATEMENT_60,INCOMESTATEMENT_61,INCOMESTATEMENT_83,INCOMESTATEMENT_85,INCOMESTATEMENT_127,\
                              INCOMESTATEMENT_14,CASHFLOWSTATEMENT_39,CASHFLOWSTATEMENT_59,CASHFLOWSTATEMENT_77,CASHFLOWSTATEMENT_82,CASHFLOWSTATEMENT_86',
                             f'ReportDate={end_date},type=1,Ispandas=1')
         if not isinstance(df_no_param, pd.DataFrame) and df_no_param.ErrorCode != 0:
@@ -814,6 +815,42 @@ class EmRawDataDownloader:
             traceback.print_exc()
             return False
 
+    def em_index_val_history(self, start_date: str, end_date: str, index_list: List[str]):
+        # 获取区间内所有交易日
+        trade_day_df = RawDataApi().get_em_tradedates(start_date, end_date)
+        if trade_day_df is None or trade_day_df.shape[0] == 0:
+            print(f'[em_index_val_history] no trade dates, return immediately (start_date){start_date} (end_date){end_date}')
+            return
+
+        df_list: List[pd.DataFrame] = []
+        # 一天一天地获取
+        for date in trade_day_df.TRADEDATES:
+            data = c.csd(index_list,
+                        "PETTM,PBMRQ,PSTTM,PCFTTM,ROE,EPSTTM,DIVIDENDYIELD",
+                        date, date,
+                        "DelType=1,period=1,adjustflag=1,curtype=1,order=1,market=0,Ispandas=1")
+            if not isinstance(data, pd.DataFrame):
+                if data.ErrorCode != 0:
+                    print(f'failed to get index val info: {data.ErrorMsg} (date){date}')
+                break
+
+            _y = pd.to_datetime(date).date().year + 1
+            another_data = c.css(index_list, "ESTPEG", f"TradeDate={date},PREDICTYEAR={_y},Ispandas=1")
+            if not isinstance(another_data, pd.DataFrame):
+                if another_data.ErrorCode != 0:
+                    print(f'failed to get index val info part 2: {another_data.ErrorMsg} (date){date}')
+                break
+            df_list.append(data.join(another_data.drop(columns='DATES'), how='outer'))
+
+        if df_list:
+            if len(df_list) == 1:
+                df = df_list[0]
+            else:
+                df = pd.concat(df_list)
+            df = df[df.drop(columns=['DATES']).notna().any(axis=1)]
+            df = df.reset_index().rename(columns={'DIVIDENDYIELD': 'DIVIDENDRATETTM'}).rename(columns=lambda x: EmIndexVal.__getattribute__(EmIndexVal, x).name)
+            self._data_helper._upload_raw(df, EmIndexVal.__table__.name)
+
     def em_index_val(self, start_date: str, end_date: str):
         try:
             # 获取区间内所有交易日
@@ -827,7 +864,7 @@ class EmRawDataDownloader:
             if index_info_df is None:
                 print(f'[em_index_val] get index info failed')
                 return False
-            em_indexes = index_info_df[index_info_df.tag_method.isin(['PE百分位', 'PB百分位','PS百分位'])].em_id
+            em_indexes = index_info_df[index_info_df.tag_method.isin(['PE百分位', 'PB百分位', 'PS百分位'])].em_id
             # 过滤掉几个特殊指数
             em_indexes = em_indexes[em_indexes.notna() & ~em_indexes.isin(['LIGBP1M.IR', 'HIBOR3M.IR', 'AU9999.SGE', 'AU0.SHF'])]
             index_list = em_indexes.to_list()
@@ -974,14 +1011,14 @@ class EmRawDataDownloader:
 
             # 中证指数爬下来的部分
             columns_list = ['id', 'name', 'num', 'id_cat', 'sector', 'top10', 'related_funds']
-            industry_df = pd.read_excel('./data/Index/industry_data.xlsx', na_values='--')
-            industry_df = industry_df[columns_list]
-            topic_df = pd.read_excel('./data/Index/topic_data.xlsx', na_values='--')
-            topic_df = topic_df[columns_list]
+            df_list: List[pd.DataFrame] = []
+            for cat in ('industry', 'topic', 'strat', 'cap'):
+                raw_df = pd.read_excel(f'./data/Index/{cat}_data.xlsx', na_values='--')
+                df_list.append(raw_df[columns_list])
 
-            df = pd.concat([industry_df, topic_df])
+            df = pd.concat(df_list)
             df['id'] = df['id'].transform(lambda x: EmRawDataDownloader._lambda_func_index_component_2({em_id.split('.')[0]: em_id for em_id in em_id_list if em_id is not None}, x))
-            df['id_cat'] = df['id_cat'].map({'行业': SectorType.industry.name, '主题': SectorType.topic.name})
+            df['id_cat'] = df['id_cat'].map({'行业': SectorType.industry.name, '主题': SectorType.topic.name, '策略': SectorType.strategy.name, '规模': SectorType.scale.name})
             df['sector'] = df['sector'].transform(EmRawDataDownloader._lambda_func_index_component_1)
             df['top10'] = df['top10'].transform(EmRawDataDownloader._lambda_func_index_component_3)
             df = df.rename(columns={'id': 'index_id'})
