@@ -1,10 +1,11 @@
 import pandas as pd
 import traceback
+import json
 from sqlalchemy import func
 from ...wrapper.mysql import (RawDatabaseConnector, BasicDatabaseConnector, DerivedDatabaseConnector, 
     ViewDatabaseConnector)
 from ...view.view_models import FundDailyCollection
-from ...view.basic_models import FundNav, FundInfo, FundRatingLatest, FundSize, FundRet
+from ...view.basic_models import FundNav, FundInfo, FundRate, FundSize, FundRet, FundBenchmark, IndexInfo
 from ...view.derived_models import FundAlpha, FundScore, FundIndicator
 from ....constant import ExchangeStatus
 
@@ -16,6 +17,7 @@ class FundDailyCollectionProcessor(object):
                     FundInfo.fund_id,
                     FundInfo.order_book_id,
                     FundInfo.wind_class_1,
+                    FundInfo.wind_class_2,
                     FundInfo.start_date,
                     FundInfo.manager_id,
                     FundInfo.company_id,
@@ -28,6 +30,41 @@ class FundDailyCollectionProcessor(object):
             except Exception as e:
                 print('Failed fill get data <err_msg> {}'.format(e))
 
+    def get_fund_benchmark_df(self):
+        def select_one_benchmark(x):
+            if not x:
+                return None
+            x = json.loads(x)
+            return max(x, key=x.get)
+
+        def get_index_name(x, index_df):
+            if not x:
+                return None
+
+            try:
+                return index_df.loc[x, 'desc_name']
+            except KeyError:
+                return None
+
+        with BasicDatabaseConnector().managed_session() as mn_session:
+            try:
+                query = mn_session.query(
+                    IndexInfo
+                )
+                index_df = pd.read_sql(query.statement, query.session.bind)
+                index_df = index_df.set_index('index_id')
+
+                query = mn_session.query(
+                    FundBenchmark.fund_id,
+                    FundBenchmark.benchmark_s,
+                )
+                df = pd.read_sql(query.statement, query.session.bind)
+                df['benchmark_s'] = df['benchmark_s'].apply(select_one_benchmark)
+                df['benchmark_name'] = df['benchmark_s'].apply(get_index_name, args=(index_df,))
+                return df
+            except Exception as e:
+                print('Failed fill get data <err_msg> {}'.format(e))
+
     def get_nav_df(self):
         with BasicDatabaseConnector().managed_session() as mn_session:
             try:
@@ -104,17 +141,26 @@ class FundDailyCollectionProcessor(object):
     def get_institution_rating_df(self):
         with BasicDatabaseConnector().managed_session() as mn_session:
             try:
-                latest_time = mn_session.query(FundRatingLatest).order_by(FundRatingLatest.update_time.desc()).limit(1).one_or_none()
-                latest_time = latest_time.update_time
+                latest_time = mn_session.query(FundRate).order_by(FundRate.datetime.desc()).limit(1).one_or_none()
+                latest_time = latest_time.datetime
                 print(latest_time)
                 query = mn_session.query(
-                    FundRatingLatest.fund_id,
-                    FundRatingLatest.zs,
-                    FundRatingLatest.sh3,
-                    FundRatingLatest.sh5,
-                    FundRatingLatest.jajx,
-                ).filter(FundRatingLatest.update_time==latest_time)
+                    FundRate.fund_id,
+                    FundRate.mornstar_3y,
+                    FundRate.mornstar_5y,
+                    FundRate.sh_3y_comp,
+                    FundRate.sh_5y_comp,
+                    FundRate.jian_comp,
+                    FundRate.merchant_3y,
+                ).filter(FundRate.datetime==latest_time)
                 rating = pd.read_sql(query.statement, query.session.bind)
+                rating = rating.rename(columns={
+                    'sh_3y_comp': 'sh3',
+                    'sh_5y_comp': 'sh5',
+                    'jian_comp': 'jajx',
+                    'merchant_3y': 'zs',
+                })
+                rating['zs'] = rating['zs'].apply(lambda x: x[0] if x else None)
                 return rating
 
             except Exception as e:
@@ -260,6 +306,11 @@ class FundDailyCollectionProcessor(object):
             print('info', funds)
             print('-' * 100)
 
+            bench = self.get_fund_benchmark_df()
+            bench = bench.drop_duplicates(subset=['fund_id'], keep='last')
+            bench = bench.set_index('fund_id')
+            print('bench', bench)
+
             nav, latest_time = self.get_nav_df()
             print(latest_time)
             nav = nav.reset_index()
@@ -290,7 +341,7 @@ class FundDailyCollectionProcessor(object):
             print('-' * 100)
 
             print('处理净值')
-            df = pd.concat([funds, nav, alpha, size, rating, score, tag_indicator], axis=1, sort=False)
+            df = pd.concat([funds, bench, nav, alpha, size, rating, score, tag_indicator], axis=1, sort=False)
             df.index.name = 'fund_id'
             print('_'*100)
             print(df)
@@ -311,6 +362,7 @@ class FundDailyCollectionProcessor(object):
             df['manager_id'] = df['manager_id'].apply(self.modify_fund_manager)
             df = df.rename(columns={
                 'wind_class_1': 'wind_class_I',
+                'wind_class_2': 'wind_class_II',
                 'start_date': 'found_date',
                 'manager_id': 'fund_manager',
                 'company_id': 'company_name',
