@@ -1,3 +1,5 @@
+
+from typing import Dict, Optional, Union
 from . import DataManager
 import pandas as pd
 import datetime
@@ -7,7 +9,7 @@ import contextlib
 from ..wrapper.mysql import RawDatabaseConnector, BasicDatabaseConnector, DerivedDatabaseConnector
 from .fund_info_filter import filter_fund_info, fund_info_update
 from ..struct import AssetPrice, FundScoreParam, TaaTunerParam, AssetTimeSpan
-from .score import FundScoreManager
+from .score import FundScoreManager, ScoreFunc
 from .data_tables import FundDataTables
 from ..view.raw_models import CSIndexComponent
 from ..view.basic_models import *
@@ -290,10 +292,10 @@ class FundDataManager(DataManager):
             return pd.DataFrame()
         return self.dts.index_pct.loc[dt]
 
-    def get_fund_score(self, dt, index_id, is_filter_c=True, fund_score_funcs=None) -> dict:
-        return self._score_manager.get_fund_score(dt, index_id, is_filter_c, fund_score_funcs)
+    def get_fund_score(self, dt, index_id, is_filter_c=True, score_func: Optional[ScoreFunc] = None) -> dict:
+        return self._score_manager.get_fund_score(dt, index_id, is_filter_c, score_func)
 
-    def get_fund_scores(self, dt, is_filter_c=True, fund_score_funcs=None) -> dict:
+    def get_fund_scores(self, dt, is_filter_c=True, fund_score_funcs: Optional[Dict[str, Union[ScoreFunc, str]]] = None) -> dict:
         return self._score_manager.get_fund_scores(dt, self.dts.index_list, is_filter_c, fund_score_funcs)
 
     def get_fund_nav(self, dt):
