@@ -165,7 +165,7 @@ class FundPosItem:
 
     fund_id: str            # 基金ID
     index_id: str           # 基金所属的大类资产
-    volume: int             # 基金份额
+    volume: float             # 基金份额
     avg_cost: float=None    # 平均成本
     update_time: datetime.date=None # 更新时间
     is_permitted_fund: bool=None  # 在白名单里或者没有白名单 True   不在白名单里或者在黑名单里  False    
