@@ -1,7 +1,7 @@
 
 from sqlalchemy import CHAR, Column, Integer, Index, BOOLEAN, text, TEXT, Enum
 from sqlalchemy.ext.declarative import declarative_base
-from sqlalchemy.dialects.mysql import DOUBLE, DATE, TINYINT, DATETIME
+from sqlalchemy.dialects.mysql import DOUBLE, DATE, TINYINT, DATETIME, MEDIUMTEXT
 
 from ...constant import SectorType, IndexPriceSource
 
@@ -51,8 +51,10 @@ class IndexInfo(Base):
     # web_id= Column(CHAR(20)) # 数据所在网页ID
     industry_tag = Column(CHAR(64))  # 行业标签
     tag_method = Column(CHAR(64))  # 估值评分采用方法
-    desc_name = Column(CHAR(64), nullable=False)  # 名称
+    desc_name = Column(CHAR(64), nullable=False, unique=True)  # 名称
     maker_name = Column(CHAR(32), nullable=False)  # 编制机构
+    # publish_date = Column(DATE, nullable=False)  # 发布日期
+    is_select = Column(BOOLEAN, nullable=False)  # 是否属于精选
     em_id = Column(CHAR(20))  # ChoiceID
     em_plate_id = Column(CHAR(20))  # Choice板块ID
     index_profile = Column(TEXT, nullable=False)  # 指数概况
@@ -70,7 +72,7 @@ class IndexComponent(Base):
     sector = Column(TEXT, nullable=False)  # 所属板块
     top10 = Column(TEXT, nullable=False)  # 前10成分及权重
     related_funds = Column(TEXT)  # 相关产品
-    all_constitu = Column(TEXT, nullable=False)  # 所有成分及权重(from Choice)
+    all_constitu = Column(MEDIUMTEXT, nullable=False)  # 所有成分及权重(from Choice)
 
 
 class StockInfo(Base):
@@ -138,6 +140,7 @@ class FundInfo(Base):
     redeem_fee_detail = Column(TEXT) # 赎回费率详情
     service_fee = Column(TEXT) # 销售服务费率
 
+
 class FundBenchmark(Base):
     '''基金业绩比较基准表'''
 
@@ -148,6 +151,7 @@ class FundBenchmark(Base):
     # datetime = Column(DATE, primary_key=True)  # 日期
     index_text = Column(TEXT, nullable=False)  # 业绩比较基准
     benchmark = Column(TEXT, nullable=False)  # 解析出来的业绩比较基准
+    benchmark_s = Column(TEXT, nullable=False)  # index转换后的业绩比较基准
     assets = Column(CHAR(32))  # 追踪的标的
     industry = Column(CHAR(64))  # 行业分类
 
