@@ -173,6 +173,23 @@ class FundIndicatorMonthly(Base):
         Index('idx_fund_indicator_monthly_datetime_monthly', 'datetime'),
     )
 
+
+class FundIndicatorAnnual(Base):
+    '''基金年度指标'''
+
+    __tablename__ = 'fund_indicator_annual'
+
+    fund_id = Column(CHAR(16), primary_key=True)  # 基金ID
+    datetime = Column(DATE, primary_key=True)  # 日期
+    beta_annual = Column(DOUBLE(asdecimal=False))  # beta
+    alpha_annual = Column(DOUBLE(asdecimal=False))  # alpha
+    excess_return_annual = Column(DOUBLE(asdecimal=False))  # 超额收益
+
+    __table_args__ = (
+        Index('idx_fund_indicator_datetime_annual', 'datetime'),
+    )
+
+
 class FundScore(Base):
     '''基金评分'''
 
@@ -254,4 +271,19 @@ class AllocationDistribution(Base):
     mmf = Column(DOUBLE(asdecimal=False)) # 货币基金权重
     national_debt = Column(DOUBLE(asdecimal=False)) #国债权重
     sp500rmb = Column(DOUBLE(asdecimal=False)) #标普500权重
-    cash = Column(DOUBLE(asdecimal=False)) #现金权重
\ No newline at end of file
+    cash = Column(DOUBLE(asdecimal=False)) #现金权重
+
+class FundAIC(Base):
+    '''基金定投收益收集'''
+
+    __tablename__ = 'fund_aic'
+
+    fund_id = Column(CHAR(20), primary_key=True)  # 基金ID
+    datetime = Column(CHAR(20), primary_key=True)  # 时间
+    y1_ret = Column(DOUBLE(asdecimal=False))  # 普通定投一年收益
+    y3_ret = Column(DOUBLE(asdecimal=False))  # 普通定投三年收益
+    y5_ret = Column(DOUBLE(asdecimal=False))  # 普通定投五年收益
+    intel_y1_ret = Column(DOUBLE(asdecimal=False))  # 智能定投一年收益
+    intel_y3_ret = Column(DOUBLE(asdecimal=False))  # 智能定投三年收益
+    intel_y5_ret = Column(DOUBLE(asdecimal=False))  # 智能定投五年收益
+
