@@ -614,6 +614,7 @@ class EmStockFinFac(Base):
     INCOMESTATEMENT_48 = Column('income_statement_48', DOUBLE(asdecimal=False)) # 营业利润
     INCOMESTATEMENT_60 = Column('income_statement_60', DOUBLE(asdecimal=False)) # 净利润
     INCOMESTATEMENT_61 = Column('income_statement_61', DOUBLE(asdecimal=False)) # 归属于母公司股东的净利润
+    INCOMESTATEMENT_83 = Column('income_statement_83', DOUBLE(asdecimal=False)) # 营业总收入
     INCOMESTATEMENT_85 = Column('income_statement_85', DOUBLE(asdecimal=False)) # 其他业务收入
     INCOMESTATEMENT_127 = Column('income_statement_127', DOUBLE(asdecimal=False)) # 利息费用
     INCOMESTATEMENT_14 = Column('income_statement_14', DOUBLE(asdecimal=False)) # 财务费用
@@ -702,7 +703,7 @@ class CSIndexComponent(Base):
     sector = Column(TEXT, nullable=False)  # 所属板块
     top10 = Column(TEXT, nullable=False)  # 前10成分及权重
     related_funds = Column(TEXT)  # 相关产品
-    all_constitu = Column(TEXT, nullable=False)  # 所有成分及权重(from Choice)
+    all_constitu = Column(MEDIUMTEXT, nullable=False)  # 所有成分及权重(from Choice)
 
 class EmFundHoldingRate(Base):
     '''Choice基金持有人比例'''
@@ -1025,4 +1026,4 @@ class EMFundHoldBond(Base):
     rank10_bond = Column(CHAR(30)) #债券名
     rank10_bond_code =  Column(CHAR(15)) # 债券id
     rank10_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
-    rank10_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
\ No newline at end of file
+    rank10_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
