@@ -21,7 +21,7 @@ class FundDailyCollection(Base):
     datetime = Column(CHAR(20), primary_key=True)  # 时间
     order_book_id = Column(CHAR(20))  # 基金代码
 
-    wind_class_I = Column(CHAR(64))  # Wind基金类型
+    wind_class_I = Column(CHAR(64))  # Wind基金类型  (混合型基金 债券型基金 股票型基金 货币市场型基金 国际(QDII)基金 另类投资基金)
     wind_class_II = Column(CHAR(64))  # Wind基金二级类型
     institution_rating = Column(CHAR(20))  # 机构评级
     found_to_now = Column(DOUBLE(asdecimal=False))  # 成立年限
@@ -55,11 +55,15 @@ class FundDailyCollection(Base):
     company_name = Column(CHAR(64))  # 基金公司
     symbol = Column(CHAR(64)) # 基金名称
     benchmark = Column(CHAR(255)) # 业绩基准
+    benchmark_s = Column(CHAR(64)) # 跟踪标的id
+    benchmark_name = Column(CHAR(64)) # 跟踪标的
 
     zs = Column(DOUBLE(asdecimal=False))  # 招商评级
     sh3 = Column(DOUBLE(asdecimal=False))  # 上海证券评级三年期
     sh5 = Column(DOUBLE(asdecimal=False))  # 上海证券评级五年期
     jajx = Column(DOUBLE(asdecimal=False))  # 济安金信评级
+    mornstar_3y = Column(DOUBLE(asdecimal=False))  # 晨星三年评级
+    mornstar_5y = Column(DOUBLE(asdecimal=False))  # 晨星五年评级
 
     track_err = Column(DOUBLE(asdecimal=False))  # 跟踪误差
     this_y_alpha = Column(DOUBLE(asdecimal=False))  # 今年以来超额收益
@@ -102,6 +106,7 @@ class FundDailyCollection(Base):
             'fund_id': '基金ID',
             'order_book_id': '基金代码',
             'wind_class_I': '基金类型',
+            'wind_class_II': '二级分类',
             'symbol': '基金名称',
             'institution_rating': '机构评级',
             'found_to_now': '成立年限',
@@ -110,8 +115,9 @@ class FundDailyCollection(Base):
 
             'exchange_status': '交易状态',
             'theme': '基金主题',
-            'adjusted_net_value': '累计净值',
+            'adjusted_net_value': '复权净值',
             'unit_net_value': '净值',
+            'acc_net_value': '累积净值',
             'change_rate': '日收益率',
             'found_date': '成立日期',
             'annualized_returns': '年化收益',
@@ -132,10 +138,15 @@ class FundDailyCollection(Base):
             'fund_manager': '基金经理',
             'company_name': '基金公司',
             'benchmark': '业绩基准',
+            'benchmark_s': '跟踪标的ID',
+            'benchmark_name': '跟踪标的',
+
             'zs': '招商评级',
             'sh3': '上证三年评级',
             'sh5': '上证五年评级',
             'jajx': '济安评级',
+            'mornstar_3y': '晨星三年评级',
+            'mornstar_5y': '晨星五年评级',
 
             'track_err': '跟踪误差',
             'this_y_alpha': '今年以来超额收益',
